==> jc-1.4.0.tar.gz: polyglot/visit/ClassSerializer.h <==
// public class polyglot.visit.ClassSerializer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e58a5b7c83230169 polyglot_visit_ClassSerializer
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_ClassSerializer_H_
#define _JC_polyglot_visit_ClassSerializer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Date$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_main_Version$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_ErrorQueue$object;
struct _jc_polyglot_util_TypeEncoder$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ClassSerializer$sub_refs	_jc_polyglot_visit_ClassSerializer$sub_refs;
typedef struct _jc_polyglot_visit_ClassSerializer$sub_nonrefs	_jc_polyglot_visit_ClassSerializer$sub_nonrefs;
typedef struct _jc_polyglot_visit_ClassSerializer$refs	_jc_polyglot_visit_ClassSerializer$refs;
typedef struct _jc_polyglot_visit_ClassSerializer$nonrefs	_jc_polyglot_visit_ClassSerializer$nonrefs;
typedef struct _jc_polyglot_visit_ClassSerializer$object	_jc_polyglot_visit_ClassSerializer$object;

typedef const struct _jc_polyglot_visit_ClassSerializer$vmethods	_jc_polyglot_visit_ClassSerializer$vmethods;
typedef const struct _jc_polyglot_visit_ClassSerializer$vtable	_jc_polyglot_visit_ClassSerializer$vtable;
typedef const struct _jc_polyglot_visit_ClassSerializer$vtype	_jc_polyglot_visit_ClassSerializer$vtype;

// Constructors
extern void _jc_polyglot_visit_ClassSerializer$method$_init$db31203d1cd8df6a(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Date$object *, struct _jc_object *, struct _jc_polyglot_main_Version$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_ClassSerializer$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
extern struct _jc_object *_jc_polyglot_visit_ClassSerializer$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ClassSerializer$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_ClassSerializer$method_info$override$1e05b257002785f7;

// Virtual methods structure
struct _jc_polyglot_visit_ClassSerializer$vmethods {
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_ClassSerializer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_ClassSerializer$vmethods	polyglot_visit_ClassSerializer;
};

// Vtype
struct _jc_polyglot_visit_ClassSerializer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ClassSerializer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ClassSerializer$sub_refs {
	struct _jc_polyglot_util_TypeEncoder$object	*te;
	struct _jc_object	*eq;
	struct _jc_java_util_Date$object	*date;
	struct _jc_object	*ts;
	struct _jc_object	*nf;
	struct _jc_polyglot_main_Version$object	*ver;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ClassSerializer$refs {
    _jc_polyglot_visit_ClassSerializer$sub_refs	polyglot_visit_ClassSerializer;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ClassSerializer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ClassSerializer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_ClassSerializer$sub_nonrefs	polyglot_visit_ClassSerializer;
};

// Object instance structure
struct _jc_polyglot_visit_ClassSerializer$object {
	_jc_polyglot_visit_ClassSerializer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ClassSerializer$vtype	*vtype;
	_jc_polyglot_visit_ClassSerializer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ClassSerializer$vtype _jc_polyglot_visit_ClassSerializer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ClassSerializer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ClassSerializer$class_object;

#endif	/* _JC_polyglot_visit_ClassSerializer_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/ClassSerializer.h <==
// public class polyglot.visit.ClassSerializer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e58a5b7c83230169 polyglot_visit_ClassSerializer
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_ClassSerializer_H_
#define _JC_polyglot_visit_ClassSerializer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Date$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_main_Version$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_ErrorQueue$object;
struct _jc_polyglot_util_TypeEncoder$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_ClassSerializer$sub_refs	_jc_polyglot_visit_ClassSerializer$sub_refs;
typedef struct _jc_polyglot_visit_ClassSerializer$sub_nonrefs	_jc_polyglot_visit_ClassSerializer$sub_nonrefs;
typedef struct _jc_polyglot_visit_ClassSerializer$refs	_jc_polyglot_visit_ClassSerializer$refs;
typedef struct _jc_polyglot_visit_ClassSerializer$nonrefs	_jc_polyglot_visit_ClassSerializer$nonrefs;
typedef struct _jc_polyglot_visit_ClassSerializer$object	_jc_polyglot_visit_ClassSerializer$object;

typedef const struct _jc_polyglot_visit_ClassSerializer$vmethods	_jc_polyglot_visit_ClassSerializer$vmethods;
typedef const struct _jc_polyglot_visit_ClassSerializer$vtable	_jc_polyglot_visit_ClassSerializer$vtable;
typedef const struct _jc_polyglot_visit_ClassSerializer$vtype	_jc_polyglot_visit_ClassSerializer$vtype;

// Constructors
extern void _jc_polyglot_visit_ClassSerializer$method$_init$db31203d1cd8df6a(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Date$object *, struct _jc_object *, struct _jc_polyglot_main_Version$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_visit_ClassSerializer$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_ClassSerializer$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_ClassSerializer$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_ClassSerializer$method_info$override$1e05b257002785f7;

// Virtual methods structure
struct _jc_polyglot_visit_ClassSerializer$vmethods {
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_ClassSerializer$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_ClassSerializer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_ClassSerializer$vmethods	polyglot_visit_ClassSerializer;
};

// Vtype
struct _jc_polyglot_visit_ClassSerializer$vtype {
	_jc_type			type;
	_jc_polyglot_visit_ClassSerializer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_ClassSerializer$sub_refs {
	struct _jc_polyglot_util_TypeEncoder$object	*te;
	struct _jc_object	*eq;
	struct _jc_java_util_Date$object	*date;
	struct _jc_object	*ts;
	struct _jc_object	*nf;
	struct _jc_polyglot_main_Version$object	*ver;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_ClassSerializer$refs {
    _jc_polyglot_visit_ClassSerializer$sub_refs	polyglot_visit_ClassSerializer;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_ClassSerializer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_ClassSerializer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_ClassSerializer$sub_nonrefs	polyglot_visit_ClassSerializer;
};

// Object instance structure
struct _jc_polyglot_visit_ClassSerializer$object {
	_jc_polyglot_visit_ClassSerializer$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_ClassSerializer$vtype	*vtype;
	_jc_polyglot_visit_ClassSerializer$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_ClassSerializer$vtype _jc_polyglot_visit_ClassSerializer$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_ClassSerializer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_ClassSerializer$class_object;

#endif	/* _JC_polyglot_visit_ClassSerializer_H_ */
